@@ -24,12 +24,17 @@
 #include "board.h"
 
 
-void load() {
+void load(char *filename) {
 	FILE *f;
 	int ch;
 	int col = 0, line = 0;
 
-	f = fopen("sample.txt", "r");
+	f = fopen(filename, "r");
+	if(f == NULL) {
+		printf("Cannot open input file: `%s'.\n", filename);
+		exit(-1);
+	}
+
 	while((ch = fgetc(f)) != EOF) {
 		switch(ch) {
 			case 'X':
